@@ -27,7 +27,7 @@ shinyServer(function(input, output) {
                r.num = as.numeric(input$r.num))
     } else {
       init.icm(s.num = as.numeric(input$s.num),
-               i.num = as.numeric(input$i.num), status.rand = FALSE)
+               i.num = as.numeric(input$i.num))
     }
   })
   control <- reactive({
@@ -49,6 +49,7 @@ shinyServer(function(input, output) {
     par(mar = c(3.5, 3.5, 1.2, 1), mgp = c(2.1, 1, 0))
     if (input$compsel == "Compartment Prevalence") {
       plot(mod(),
+           popfrac = TRUE,
            mean.line = input$showmean,
            sim.lines = input$showsims,
            qnts = showqnts(),
