@@ -65,21 +65,21 @@ shinyUI(fluidPage(
                                     label = "Recovery Rate",
                                     min = 0,
                                     value = 0)),
-      numericInput(inputId = "b.rate",
-                   label = "Birth Rate",
+      numericInput(inputId = "a.rate",
+                   label = "Arrival Rate",
                    min = 0,
                    value = 0.0),
       numericInput(inputId = "ds.rate",
-                   label = "Death Rate (Sus.)",
+                   label = "Departure Rate (Sus.)",
                    min = 0,
                    value = 0.0),
       numericInput(inputId = "di.rate",
-                   label = "Death Rate (Inf.)",
+                   label = "Departure Rate (Inf.)",
                    min = 0,
                    value = 0.0),
       conditionalPanel("input.modtype == 'SIR'",
                        numericInput(inputId = "dr.rate",
-                                    label = "Death Rate (Rec.)",
+                                    label = "Departure Rate (Rec.)",
                                     min = 0,
                                     value = 0.0))
     ), #End sidebarPanel
@@ -201,7 +201,7 @@ shinyUI(fluidPage(
            browser (no R needed)", a("here.", href = "http://statnet.shinyapps.io/epiicm/")),
          br(),
          strong("Authors"), p("Samuel M. Jenness, Department of Epidemiology,
-                              University of Washington"),
+                              Emory University"),
          p("Steven M. Goodreau, Department of Anthropology,
            University of Washington"),
          p("Martina Morris, Departments of Statistics and Sociology,
