@@ -56,7 +56,7 @@ test_that("color_tea", {
 test_that("calc_eql for dcm", {
   param <- param.dcm(inf.prob = 0.2, inf.prob.g2 = 0.1, act.rate = 0.5,
                      balance = "g1", rec.rate = 1 / 50, rec.rate.g2 = 1 / 50,
-                     b.rate = 1 / 100, b.rate.g2 = NA, ds.rate = 1 / 100,
+                     a.rate = 1 / 100, a.rate.g2 = NA, ds.rate = 1 / 100,
                      ds.rate.g2 = 1 / 100, di.rate = 1 / 90, di.rate.g2 = 1 / 90)
   init <- init.dcm(s.num = 500, i.num = 1,
                    s.num.g2 = 500, i.num.g2 = 1)
@@ -75,7 +75,7 @@ test_that("calc_eql for dcm", {
 test_that("calc_eql for icm", {
   skip_on_cran()
   set.seed(1)
-  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, b.rate = 1/100,
+  param <- param.icm(inf.prob = 0.2, act.rate = 0.25, a.rate = 1/100,
                      ds.rate = 1/100, di.rate = 1/90)
   init <- init.icm(s.num = 500, i.num = 1)
   control <- control.icm(type = "SI", nsteps = 500, nsims = 1, verbose = FALSE)
@@ -137,12 +137,12 @@ test_that("bipvals", {
 
 test_that("check_bip_degdist", {
   expect_output(check_bip_degdist(num.m1 = 500, num.m2 = 500,
-                    deg.dist.m2 = c(0.40, 0.55, 0.03, 0.02),
-                    deg.dist.m1 = c(0.48, 0.41, 0.08, 0.03)),
+                                  deg.dist.m2 = c(0.40, 0.55, 0.03, 0.02),
+                                  deg.dist.m1 = c(0.48, 0.41, 0.08, 0.03)),
                 "-0.015 Rel Diff")
   expect_output(check_bip_degdist(num.m1 = 500, num.m2 = 500,
-                    deg.dist.m1 = c(0.40, 0.55, 0.04, 0.01),
-                    deg.dist.m2 = c(0.48, 0.41, 0.08, 0.03)),
+                                  deg.dist.m1 = c(0.40, 0.55, 0.04, 0.01),
+                                  deg.dist.m2 = c(0.48, 0.41, 0.08, 0.03)),
                 "Edges balanced")
   expect_output(check_bip_degdist(num.m1 = 500, num.m2 = 500,
                                   deg.dist.m1 = c(0.45, 0.55, 0.04, 0.01),
@@ -161,8 +161,8 @@ test_that("edgelist_censor", {
   target.stats <- 50
   coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 20)
   est <- netest(nw, formation, target.stats, coef.diss, verbose = FALSE)
-  sim <- netdx(est, nsims = 1, nsteps = 100, verbose = FALSE)
-  el <- sim$edgelist[[1]]
+  sim <- netdx(est, nsims = 1, nsteps = 100, keep.tedgelist = TRUE, verbose = FALSE)
+  el <- as.data.frame(sim)
   expect_is(edgelist_censor(el), "matrix")
 })
 
@@ -188,3 +188,42 @@ test_that("get_degree", {
 
   all.equal(ergm.method, deg.net, deg.el)
 })
+
+test_that("dissolution_coefs returns appropriate error for incompatible departure rate",{
+  #Dividing by zero:
+  d.rate_ <- round(1-sqrt(59/60), 5)
+  err.msg <- paste("The competing risk of departure is too high for the given",
+                   " duration of ", 60, "; specify a d.rate lower than ",
+                   d.rate_,".",sep="")
+  dissolution = ~offset(edges)
+  expect_that(dissolution_coefs(dissolution, duration = 60, d.rate = 1/60), throws_error(err.msg))
+  expect_that(dissolution_coefs(dissolution, duration = 60, d.rate = 0.01), throws_error(err.msg))
+})
+
+
+test_that("get_formula_term_attr checks", {
+  nw <- network.initialize(100, directed = FALSE)
+
+  expect_null(get_formula_term_attr(~edges, nw))
+
+  nw <- network.initialize(100, directed = FALSE)
+  riskg <- sample(rep(1:2, each = 50))
+  race <- sample(rep(0:1, each = 50))
+  nw <- set.vertex.attribute(nw, "riskg", riskg)
+  nw <- set.vertex.attribute(nw, "race", race)
+  expect_null(get_formula_term_attr(~edges, nw))
+
+  expect_equal(get_formula_term_attr(~edges + nodefactor("race"), nw), "race")
+  expect_equal(get_formula_term_attr(~edges + nodefactor("race") + nodematch("riskg"), nw),
+               c("riskg", "race"))
+  expect_equal(get_formula_term_attr(~edges + nodefactor(c("race", "riskg")) + nodematch("riskg"), nw),
+               c("riskg", "race"))
+
+})
+
+test_that("Users using birth parameters are informed of change in language",{
+  expect_that(param.net(b.rate=2), shows_message("EpiModel 1.7.0 onward renamed the birth rate parameter b.rate to a.rate. See documentation for details."))
+  expect_that(param.dcm(b.rate=2), shows_message("EpiModel 1.7.0 onward renamed the birth rate parameter b.rate to a.rate. See documentation for details."))
+  expect_that(param.icm(b.rate=2), shows_message("EpiModel 1.7.0 onward renamed the birth rate parameter b.rate to a.rate. See documentation for details."))
+  expect_that(param.icm(b.rand=0.5), shows_message("EpiModel 1.7.0 onward renamed the stochastic birth model flag b.rand to a.rand. See documentation for details."))
+ })
